@@ -603,7 +603,7 @@ static void finalize_shell(mysqlsh::Command_line_shell *shell) {
   shell->restore_print();
 
   // shell needs to be destroyed before global_end() is called, because it
-  // needs to call destructors of JS contexts before V8 is shut down
+  // needs to call destructors of JS contexts
   delete shell;
 
   mysqlsh::global_end();
@@ -851,7 +851,8 @@ int main(int argc, char **argv) {
           }
 
           // Connect to the requested instance
-          shell->connect(target, options.recreate_database);
+          shell->connect(target, options.recreate_database, true,
+                         !options.prompt_password);
 
           // If redirect is requested, then reconnect to the right instance
           handle_redirect(shell, options.redirect_session);
