@@ -1,16 +1,18 @@
 /*
- * Copyright (c) 2017, 2023, Oracle and/or its affiliates.
+ * Copyright (c) 2017, 2024, Oracle and/or its affiliates.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2.0,
  * as published by the Free Software Foundation.
  *
- * This program is also distributed with certain software (including
- * but not limited to OpenSSL) that is licensed under separate terms, as
- * designated in a particular file or component or in included license
+ * This program is designed to work with certain software (including
+ * but not limited to OpenSSL) that is licensed under separate terms,
+ * as designated in a particular file or component or in included license
  * documentation.  The authors of MySQL hereby grant you an additional
  * permission to link the program and your derivative works with the
- * separately licensed software that they have included with MySQL.
+ * separately licensed software that they have either included with
+ * the program or referenced in the documentation.
+ *
  * This program is distributed in the hope that it will be useful,  but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
@@ -302,7 +304,7 @@ TEST_F(Dba_common_test, resolve_instance_ssl_cluster_with_ssl_required) {
 
   testutil->expect_prompt(
       "Should the configuration be changed accordingly? [y/N]: ", "y");
-#ifdef HAVE_V8
+#ifdef HAVE_JS
   execute(
       "var c = dba.createCluster('sample', {memberSslMode:'REQUIRED', "
       "gtidSetIsComplete: true})");
@@ -560,7 +562,7 @@ TEST_F(Dba_common_test, resolve_instance_ssl_cluster_with_ssl_disabled) {
 
   testutil->expect_prompt(
       "Should the configuration be changed accordingly? [y/N]: ", "y");
-#ifdef HAVE_V8
+#ifdef HAVE_JS
   execute(
       "var c = dba.createCluster('sample', {memberSslMode:'DISABLED', "
       "gtidSetIsComplete: true})");
@@ -1020,7 +1022,7 @@ TEST_F(Dba_common_test, super_read_only_server_on_flag_true) {
 
   try {
     auto read_only = mysqlsh::dba::validate_super_read_only(
-        mysqlshdk::mysql::Instance(session), true, false);
+        mysqlshdk::mysql::Instance(session), true);
     EXPECT_TRUE(read_only);
   } catch (const shcore::Exception &e) {
     SCOPED_TRACE(e.what());
@@ -1048,7 +1050,7 @@ TEST_F(Dba_common_test, super_read_only_server_on_flag_false_open_sessions) {
 
   try {
     mysqlsh::dba::validate_super_read_only(mysqlshdk::mysql::Instance(session),
-                                           false, false);
+                                           false);
     SCOPED_TRACE("Unexpected success calling validate_super_read_only");
     ADD_FAILURE();
   } catch (const shcore::Exception &e) {
@@ -1071,7 +1073,7 @@ TEST_F(Dba_common_test, super_read_only_server_on_flag_false_no_open_sessions) {
   session->query("set global super_read_only = 1");
   try {
     mysqlsh::dba::validate_super_read_only(mysqlshdk::mysql::Instance(session),
-                                           false, false);
+                                           false);
     SCOPED_TRACE("Unexpected success calling validate_super_read_only");
     ADD_FAILURE();
   } catch (const shcore::Exception &e) {
@@ -1094,7 +1096,7 @@ TEST_F(Dba_common_test, super_read_only_server_off_flag_true) {
 
   try {
     auto read_only = mysqlsh::dba::validate_super_read_only(
-        mysqlshdk::mysql::Instance(session), true, false);
+        mysqlshdk::mysql::Instance(session), true);
     EXPECT_FALSE(read_only);
   } catch (const shcore::Exception &e) {
     SCOPED_TRACE(e.what());
@@ -1118,7 +1120,7 @@ TEST_F(Dba_common_test, super_read_only_server_off_flag_false) {
 
   try {
     auto read_only = mysqlsh::dba::validate_super_read_only(
-        mysqlshdk::mysql::Instance(session), false, false);
+        mysqlshdk::mysql::Instance(session), false);
     EXPECT_FALSE(read_only);
   } catch (const shcore::Exception &e) {
     SCOPED_TRACE(e.what());
@@ -1926,4 +1928,36 @@ TEST_F(Dba_common_test, resolve_gr_local_address) {
 
   testutil->destroy_sandbox(_mysql_sandbox_ports[0] * 10 + 1);
 }
+
+TEST_F(Dba_common_test, set_wait_recovery) {
+  mysqlsh::dba::cluster::Add_instance_options options;
+
+  options.set_wait_recovery(mysqlsh::dba::kWaitRecovery, 0);
+  EXPECT_EQ(options.get_wait_recovery(),
+            mysqlsh::dba::Recovery_progress_style::NOWAIT);
+
+  options.set_wait_recovery(mysqlsh::dba::kWaitRecovery, 1);
+  EXPECT_EQ(options.get_wait_recovery(),
+            mysqlsh::dba::Recovery_progress_style::NOINFO);
+
+  options.set_wait_recovery(mysqlsh::dba::kWaitRecovery, 2);
+  EXPECT_EQ(options.get_wait_recovery(),
+            mysqlsh::dba::Recovery_progress_style::TEXTUAL);
+
+  options.set_wait_recovery(mysqlsh::dba::kWaitRecovery, 3);
+  EXPECT_EQ(options.get_wait_recovery(),
+            mysqlsh::dba::Recovery_progress_style::PROGRESSBAR);
+
+  options.set_wait_recovery(mysqlsh::dba::kRecoveryProgress, 0);
+  EXPECT_EQ(options.get_wait_recovery(),
+            mysqlsh::dba::Recovery_progress_style::NOINFO);
+
+  options.set_wait_recovery(mysqlsh::dba::kRecoveryProgress, 1);
+  EXPECT_EQ(options.get_wait_recovery(),
+            mysqlsh::dba::Recovery_progress_style::TEXTUAL);
+
+  options.set_wait_recovery(mysqlsh::dba::kRecoveryProgress, 2);
+  EXPECT_EQ(options.get_wait_recovery(),
+            mysqlsh::dba::Recovery_progress_style::PROGRESSBAR);
+}
 }  // namespace testing
